<template>
  <div>
    <el-dialog v-model="dialogVisible" :title="title" width="600" :close-on-click-modal="false"
      :before-close="handleClose">
      <el-form ref="formRef" style="max-width: 400px; margin: 0 auto" :model="formData" :rules="rules" label-width="auto">
        <el-form-item label="客户名称" prop="customerName">
          <el-input v-model="formData.customerName" placeholder="请输入客户名称" />
        </el-form-item>
        <el-form-item label="纳税人识别号" prop="taxpayerId">
          <el-input v-model="formData.taxpayerId" placeholder="请输入纳税人识别号" />
        </el-form-item>
        <el-form-item label="经营地址" prop="bids">
          <el-cascader placeholder="请选择经营地址" size="default" :options="addressSelectOptions" v-model="formData.bids"
           :props="cascaderProps" @change="handleChange">
          </el-cascader>
        </el-form-item>
        <el-form-item label="经营详细地址" prop="businessAddress">
          <el-input v-model="formData.businessAddress" placeholder="请输入经营详细地址" />
        </el-form-item>
        <el-form-item label="开户行" prop="bankName">
          <el-input v-model="formData.bankName" placeholder="请输入开户行" />
        </el-form-item>
        <el-form-item label="银行账户" prop="bankAccount">
          <el-input v-model="formData.bankAccount" placeholder="请输入银行账户" />
        </el-form-item>
        <el-form-item label="联系人" prop="contactPerson">
          <el-input v-model="formData.contactPerson" placeholder="请输入联系人" />
        </el-form-item>
        <el-form-item label="联系电话" prop="contactPhone">
          <el-input v-model="formData.contactPhone" placeholder="请输入联系电话" />
        </el-form-item>
  
        <el-form-item label="联系人地址" prop="cids">
          <el-cascader placeholder="请选择联系人地址" size="default" :options="addressSelectOptions" v-model="formData.cids"
            :props="cascaderProps" @change="handleChange">
          </el-cascader>
        </el-form-item>
        <el-form-item label="联系人详细" prop="contactAddress">
          <el-input v-model="formData.contactAddress" placeholder="请输入联系人详细地址" />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="submitForm">
            确定
          </el-button>
          <el-button v-if="addOrEdit === 'edit'" @click="resetForm">重置</el-button>
          <el-button v-if="addOrEdit === 'add'" @click="cancelForm">取消</el-button>
        </el-form-item>
      </el-form>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref, watch, onMounted } from "vue";
import { getAreaOptions } from "@/api/system/area.js";
import addressList from "@/api/jsonApi/areaList.json";
import { addOrEditCustomer } from "@/api/basicInformation/customer";

const props = defineProps({
  beforeClose: {
    type: Function,
    default: () => { },
  },
  form: {
    type: Object,
    default: () => ({}),
  },
  addOrEdit: {
    type: String,
    default: "add",
  },
  title: {
    type: String,
    default: "",
  },
});

const handleChange = (value) => {
  console.log(value);
};
const emit = defineEmits([
  "submit",
  "handleBeforeClose",
  "update:customerDialogFormVisible",
]);
onMounted(() => {
  fetchAreaOptions()
})

// 修改树形选择的映射
const cascaderProps = ref({
  value: 'id', // 指定value字段为id
  label: 'label', // 指定label字段
  children: 'children' // 指定子节点字段
})

// 地址选择数据
const addressSelectOptions = ref([]);
const fetchAreaOptions = async () => {
  addressSelectOptions.value = [];

  const res = await getAreaOptions();
  if (res.code === 200) {
    addressSelectOptions.value = res.data;
  }
}
// 表单引用
const formRef = ref(null);
// 表单数据
const formData = ref({ ...props.form });
// 弹窗可见性
const dialogVisible = defineModel("customerDialogFormVisible", {
  required: true,
  type: Boolean,
});

// 监听外部传入的表单数据变化
watch(
  () => props.form,
  (newVal) => {
    formData.value = { ...newVal };
  },
  { deep: true }
);
watch(
  () => props.form,
  (newVal) => {
    formData.value = { ...newVal };
  },
  { deep: true }
);

// 监听内部弹窗状态变化
watch(
  () => dialogVisible.value,
  (newVal) => {
    emit("update:customerDialogFormVisible", newVal);
  }
);

// 提交表单
const submitForm = async () => {
  if (!formRef.value) return;
  await formRef.value.validate(async (valid, fields) => {
    if (valid) {
      const obj = ref({});
      if (props.title.includes('新增')) {
        let result = await addOrEditCustomer({
          ...formData.value,
        })
        obj.value = {
          title: "新增",
          ...formData.value,
          result
        };
      } else {
        delete formData.value.createTime
        delete formData.value.updateTime
        let result = await addOrEditCustomer({
          ...formData.value,
        })
        console.log(result);
        obj.value = {
          title: "编辑",
          ...formData.value,
          result
        };
      }
      emit("submit", obj.value);
    }
  });
};
// 取消表单
const cancelForm = () => {
  emit("update:customerDialogFormVisible", false);
  formData.value = {};
};
// 重置表单
const resetForm = () => {
  if (!formRef.value) return;
  formRef.value.resetFields();
};
// 关闭弹窗
const handleClose = () => {
  // 触发父组件的关闭函数
  emit("handleBeforeClose");
  emit("update:customerDialogFormVisible", false);
};
const rules = reactive({
  customerName: [
    { required: true, message: "请输入供货商名称", trigger: "blur" },
  ],
  taxpayerId: [
    { required: true, message: "请正确输入纳税人识别号", trigger: "blur" },
    { min: 17, max: 20, message: "请输入17-20位纳税人识别号", trigger: "blur" },
  ],
  address: [
    {
      required: true,
      message: "请选择经营地址",
      trigger: "change",
    },
  ],
  bankAccount: [{ required: true, message: "请输入银行账户", trigger: "blur" }],
  bankName: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contactPerson: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  cids: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  bids: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contactPhone: [
    { required: true, message: "请输入联系人", trigger: "blur" },
    { min: 11, max: 11, message: "请输入11位联系人电话", trigger: "blur" },
  ],
});
</script>

<style lang="sass" scoped>
</style>